@@ -87,12 +87,6 @@ public:
 
     void changeIconOf(UMLObject *o, Icon_Utils::IconType to);
 
-    UMLObject *createUMLObject(UMLListViewItem * item, UMLObject::ObjectType type);
-    bool createChildUMLObject(UMLListViewItem * item, UMLObject::ObjectType type);
-    UMLView* createDiagram(UMLListViewItem * item, Uml::DiagramType::Enum type);
-
-    QString uniqueDiagramName(Uml::DiagramType::Enum type);
-
     bool isUnique(UMLListViewItem * item, const QString &name);
 
     void setSelected(UMLListViewItem * item, bool state) { setItemSelected((QTreeWidgetItem*)item, state);  }
@@ -103,8 +97,6 @@ public:
     UMLListViewItem * moveObject(Uml::ID::Type srcId, UMLListViewItem::ListViewType srcType,
                                  UMLListViewItem *newParent);
 
-    bool itemRenamed(UMLListViewItem* item, int col);
-
     void closeDatatypesFolder();
 
     UMLListViewItem *theRootView() { return m_rv; }
@@ -167,7 +159,7 @@ public slots:
 
     void slotMenuSelection(QAction* action);
 
-    void slotDropped(QDropEvent* de, UMLListViewItem* parent, UMLListViewItem* item);
+    void slotDropped(QDropEvent* de, UMLListViewItem* target);
 
     void expandAll(UMLListViewItem *item);
     void collapseAll(UMLListViewItem *item);
@@ -194,6 +186,7 @@ private:
     bool             m_bStartedCopy;
     bool m_bCreatingChildObject;  ///< when creating an attribute or an operation to stop it adding a second listViewItem
     QPoint m_dragStartPosition;
+    QMimeData* m_dragCopyData;
 };
 
 #endif
