@@ -52,7 +52,7 @@ PinWidget::PinWidget(UMLScene* scene, UMLWidget* a, Uml::ID::Type id)
     m_nY = y() < getMinY() ? getMinY() : y();
 
     m_pName = new FloatingTextWidget(scene, Uml::TextRole::Floating, "");
-    scene->setupNewWidget(m_pName);
+    m_scene->addFloatingTextWidget(m_pName);
     m_pName->setX(0);
     m_pName->setY(0);
 
@@ -268,7 +268,7 @@ bool PinWidget::loadFromXMI(QDomElement& qElement)
     QDomElement element = node.toElement();
     if (!element.isNull()) {
         QString tag = element.tagName();
-        if (tag == "floatingtext") {
+        if (tag == "floatingtext" || tag == "UML::FloatingTextWidget") {
             m_pName = new FloatingTextWidget(m_scene, Uml::TextRole::Floating, m_Text, textId);
             if(! m_pName->loadFromXMI(element)) {
                 // Most likely cause: The FloatingTextWidget is empty.
